summaryrefslogtreecommitdiffstats
path: root/content/browser/ssl/ssl_policy_backend.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/browser/ssl/ssl_policy_backend.h')
-rw-r--r--content/browser/ssl/ssl_policy_backend.h20
1 files changed, 14 insertions, 6 deletions
diff --git a/content/browser/ssl/ssl_policy_backend.h b/content/browser/ssl/ssl_policy_backend.h
index 18ec580..06ea23e 100644
--- a/content/browser/ssl/ssl_policy_backend.h
+++ b/content/browser/ssl/ssl_policy_backend.h
@@ -10,6 +10,7 @@
#include "base/basictypes.h"
#include "base/strings/string16.h"
+#include "net/cert/cert_status_flags.h"
#include "net/cert/x509_certificate.h"
namespace content {
@@ -26,15 +27,22 @@ class SSLPolicyBackend {
// Returns whether the specified host ran insecure content.
bool DidHostRunInsecureContent(const std::string& host, int pid) const;
- // Records that |cert| is permitted to be used for |host| in the future.
- void DenyCertForHost(net::X509Certificate* cert, const std::string& host);
+ // Records that |cert| is not permitted to be used for |host| in the future,
+ // for a specific error type.
+ void DenyCertForHost(net::X509Certificate* cert,
+ const std::string& host,
+ net::CertStatus error);
- // Records that |cert| is not permitted to be used for |host| in the future.
- void AllowCertForHost(net::X509Certificate* cert, const std::string& host);
+ // Records that |cert| is permitted to be used for |host| in the future, for
+ // a specific error type.
+ void AllowCertForHost(net::X509Certificate* cert,
+ const std::string& host,
+ net::CertStatus error);
// Queries whether |cert| is allowed or denied for |host|.
- net::CertPolicy::Judgment QueryPolicy(
- net::X509Certificate* cert, const std::string& host);
+ net::CertPolicy::Judgment QueryPolicy(net::X509Certificate* cert,
+ const std::string& host,
+ net::CertStatus error);
private:
// SSL state specific for each host.